Fix spelling mistakes using codespell

This commit corrects various spelling mistakes throughout the
repository. The corrections were made automatically using `codespell`[1]
tool.

[1]: https://github.com/codespell-project/codespell

Change-Id: Iae81201889d1bb4ca324243b863948cb60420ae7
Signed-off-by: Manojkiran Eda <manojkiran.eda@gmail.com>
diff --git a/ibm_vpd_utils.cpp b/ibm_vpd_utils.cpp
index 9247870..de38c6e 100644
--- a/ibm_vpd_utils.cpp
+++ b/ibm_vpd_utils.cpp
@@ -874,9 +874,9 @@
         }
         else
         {
             // missing required informations
             std::cerr
-                << "VPD inventory JSON missing basic informations of presence "
+                << "VPD inventory JSON missing basic information of presence "
                    "for this FRU : ["
                 << file << "]. Executing executePostFailAction." << std::endl;
 
@@ -950,9 +950,9 @@
         }
         else
         {
             // missing required informations
             std::cerr
-                << "VPD inventory JSON missing basic informations of preAction "
+                << "VPD inventory JSON missing basic information of preAction "
                    "for this FRU : ["
                 << file << "]. Executing executePostFailAction." << std::endl;
 
@@ -1075,7 +1075,7 @@
                     "xyz.openbmc_project.Inventory.Item.Dimm") !=
                 item["extraInterfaces"].end())
             {
-                // check added here for DDIMM only workarround
+                // check added here for DDIMM only workaround
                 vpdType dimmType = vpdTypeCheck(vpdVector);
                 if (dimmType == constants::DDR4_DDIMM_MEMORY_VPD ||
                     dimmType == constants::DDR5_DDIMM_MEMORY_VPD)
@@ -874,9 +874,9 @@
         else
         {
-            // missing required informations
+            // missing required information
             std::cerr
@@ -950,9 +950,9 @@
         else
         {
-            // missing required informations
+            // missing required information
             std::cerr